Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2129)

Unified Diff: Source/platform/heap/ThreadState.h

Issue 413133006: Revert "Revert of [oilpan]: Change marking to do precise roots first and conservative second. (http… (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: moved RELEASE_ASSERT Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/platform/heap/HeapTest.cpp ('k') | Source/platform/heap/ThreadState.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/platform/heap/ThreadState.h
diff --git a/Source/platform/heap/ThreadState.h b/Source/platform/heap/ThreadState.h
index 1aa6c22a49eed2bb935fcbb51d62600867150590..f82a434634b0bdf0f46b2dad0fe36fdb2d888500 100644
--- a/Source/platform/heap/ThreadState.h
+++ b/Source/platform/heap/ThreadState.h
@@ -245,8 +245,11 @@ public:
static void attachMainThread();
static void detachMainThread();
- // Trace all GC roots, called when marking the managed heap objects.
- static void visitRoots(Visitor*);
+ // Trace all persistent roots, called when marking the managed heap objects.
+ static void visitPersistentRoots(Visitor*);
+
+ // Trace all objects found on the stack, used when doing conservative GCs.
+ static void visitStackRoots(Visitor*);
// Associate ThreadState object with the current thread. After this
// call thread can start using the garbage collected heap infrastructure.
@@ -510,7 +513,6 @@ public:
HeapStats& statsAfterLastGC() { return m_statsAfterLastGC; }
void setupHeapsForTermination();
- void visitLocalRoots(Visitor*);
private:
explicit ThreadState();
@@ -561,8 +563,6 @@ private:
// and lazily construct ThreadState in it using placement new.
static uint8_t s_mainThreadStateStorage[];
- void trace(Visitor*);
-
ThreadIdentifier m_thread;
OwnPtr<PersistentNode> m_persistents;
StackState m_stackState;
« no previous file with comments | « Source/platform/heap/HeapTest.cpp ('k') | Source/platform/heap/ThreadState.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698